package com.water.watersys.components;

import lombok.Getter;

@Getter
public class Result<T> {

    private Integer status;       // 状态码

    private String msg;     // 返回消息

    private T data;         // 返回数据

    public Result() {
    }
    
    public Result(Integer status, String msg, T data) {
        this.status = status;
        this.msg = msg;
        this.data = data;
    }

    private static <T> Result<T> build(T data) {
        Result<T> result = new Result<>();

        if (data != null) {
            result.data = data;
        }

        return result;
    }

    private static <T> Result<T> build(T data, Integer code, String msg) {

        return new Result<>(code, msg, data);
    }

    private static <T> Result<T> build(T data, ResultCodeEnum resultCodeEnum) {

        return new Result<>(resultCodeEnum.getCode(), resultCodeEnum.getMsg(), data);
    }

    /**
     * 200 无参数成功
     */
    public static <T> Result<T> success() {

        return build(null, ResultCodeEnum.SUCCESS);
    }

    /**
     * 200 有参数成功
     */
    public static <T> Result<T> success(T data) {

        return build(data, ResultCodeEnum.SUCCESS);
    }

    /**
     * 201 无参创建资源成功
     */
    public static <T> Result<T> createSuccess() {

        return build(null, ResultCodeEnum.CREATE_SUCCESS);
    }

    /**
     * 201 有参创建资源成功
     */
    public static <T> Result<T> createSuccess(T data) {

        return build(data, ResultCodeEnum.CREATE_SUCCESS);
    }

    /**
     * 204 删除资源成功，无参数
     */
    public static <T> Result<T> removeSuccess() {

        return build(null, ResultCodeEnum.REMOVE_SUCCESS);
    }

    /**
     * 204 删除资源成功，有参数
     */
    public static <T> Result<T> removeSuccess(T data) {

        return build(data, ResultCodeEnum.REMOVE_SUCCESS);
    }

    /**
     * 400 失败，无参数
     */
    public static <T> Result<T> fail() {

        return build(null, ResultCodeEnum.FAIL);
    }

    /**
     * 400 失败，有参数
     */
    public static <T> Result<T> fail(T data) {

        return build(data, ResultCodeEnum.FAIL);
    }

    /**
     * 401 验证失败，无参数
     */
    public static <T> Result<T> verificationFail() {

        return build(null, ResultCodeEnum.VERIFICATION_FAIL);
    }

    /**
     * 401 验证失败，有参数
     */
    public static <T> Result<T> verificationFail(T data) {

        return build(data, ResultCodeEnum.VERIFICATION_FAIL);
    }

    /**
     * 402 创建资源失败，无参
     */
    public static <T> Result<T> createFail() {

        return build(null, ResultCodeEnum.CREATE_FAIL);
    }

    public static <T> Result<T> deleteFail() {
        return build(null, ResultCodeEnum.REMOVE_FAIL);
    }

    /**
     * 402 创建资源失败，有参数
     */
    public static <T> Result<T> createFail(T data) {

        return build(data, ResultCodeEnum.CREATE_FAIL);
    }

    /**
     * 404 资源不存在
     */
    public static <T> Result<T> notFoundFail() {

        return build(null, ResultCodeEnum.NOT_FOUND);
    }

    /**
     * 500 服务端错误
     */
    public static <T> Result<T> error() {

        return build(null, ResultCodeEnum.ERROR);
    }

    /**
     * 500 服务端错误，带参
     */
    public static <T> Result<T> error(T data) {

        return build(data, ResultCodeEnum.ERROR);
    }
}

