package com.water.watersys.controller;

import cn.dev33.satoken.stp.StpUtil;
import com.water.watersys.components.Result;
import com.water.watersys.model.domain.RoleSys;
import com.water.watersys.model.domain.UserSys;
import com.water.watersys.model.dto.SearchUserDto;
import com.water.watersys.model.vo.UserOv;
import com.water.watersys.service.RoleSysService;
import com.water.watersys.service.UserSysService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import org.springframework.web.bind.annotation.*;

import java.util.List;
@RestController
@CrossOrigin
@Tag(name = "员工", description = "员工")
public class EmpController {
    @Resource
    private UserSysService userSysService;

    @Resource
    private RoleSysService roleSysService;
    @Operation(summary = "获取所有员工", description = "获取所有员工")
    @GetMapping("/getEmpList")
    public Result<List<UserOv>> getUserList(SearchUserDto searchUserDto) {
        String loginId = (String) StpUtil.getLoginId();
        List<UserOv> user = userSysService.getUserList(loginId,searchUserDto);
        user.forEach(item -> {
            List<RoleSys> role = roleSysService.getRole(item.getId());
            item.setRole(role);
        });
        return Result.success(user);
    }

    @Operation(summary = "添加员工", description = "添加员工")
    @PostMapping("/postEmpUser")
    public Result<String> postEmpUser(@RequestBody UserSys userSys){
        userSys.setParentId((Integer) StpUtil.getLoginId());
        int id =  userSysService.postEmpUser(userSys);
        if (id != 0) {
            return Result.success();
        }else {
            return Result.createFail();
        }
    }

    @Operation(summary = "删除员工", description = "删除员工")
    @PostMapping("/deleteEmpUser")
    public Result<String> deleteEmpUser(Integer id){
        int ids = userSysService.deleteEmpUser(id);
        if (ids != 0) {
            return Result.success();
        }else {
            return Result.createFail();
        }
    }

    @Operation(summary = "修改员工状态", description = "修改员工状态")
    @PutMapping("/putEmpStatus")
    public Result<String> putEmpStatus(Integer id ,Integer status){
        Integer ids = userSysService.putEmpStatus(id,status);
        if (ids != 0) {
            return Result.success();
        }else {
            return Result.createFail();
        }
    }
}
