package com.water.watersys.controller;

import cn.dev33.satoken.stp.StpUtil;
import com.water.watersys.components.Result;
import com.water.watersys.model.domain.UserSys;
import com.water.watersys.model.dto.LoginDto;
import com.water.watersys.service.UserSysService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import org.springframework.web.bind.annotation.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

@RestController
@CrossOrigin
@Tag(name = "登录注册", description = "用户登录注册")
public class LoginController {
    @Resource
    private UserSysService userSysService;

    static Logger logger= LoggerFactory.getLogger(LoginController.class);
    @Operation(summary = "登录", description = "登录")
    @PostMapping("/login")
    public Result<String> login(@RequestBody LoginDto loginDto) {
        Integer id = userSysService.login(loginDto);
        logger.info("id:{}",id);
        logger.info("loginDto:{}",loginDto);
        if (id != 0) {
            StpUtil.login(id);
            return Result.success(StpUtil.getTokenValue());
        }else {
            return Result.verificationFail();
        }
    }

    @Operation(summary = "退出登录", description = "退出登录")
    @PostMapping("/logout")
    public Result logout(){
        StpUtil.logout(StpUtil.getLoginId());
        return Result.success(StpUtil.getTokenValue());
    }


    @Operation(summary = "注册", description = "注册")
    @PostMapping("/register")
    public Result register(@RequestBody UserSys userSys) {
        int index = userSysService.register(userSys);
        logger.info("注册信息:{}",userSys);
        if (index > 0) {
            return Result.success(index);
        }else {
            return Result.createFail();
        }
    }


}



