package com.water.watersys.service.impl;

import com.water.watersys.service.InvitationService;
import org.springframework.stereotype.Service;
import org.springframework.data.redis.core.StringRedisTemplate;

import java.util.UUID;
import java.util.concurrent.TimeUnit;

@Service
public class InvitationServiceImpl implements InvitationService {

    private final StringRedisTemplate redisTemplate;

    // 邀请码前缀，用于Redis key
    private static final String INVITATION_PREFIX = "invite:";


    public InvitationServiceImpl(StringRedisTemplate redisTemplate) {
        this.redisTemplate = redisTemplate;
    }

    @Override
    public String generateInvitationCode(Integer time, String loginId) {
        String code = generateRandomCode();
        String key = INVITATION_PREFIX + code;
        System.out.println(loginId);
        // 存储到Redis，5分钟后自动过期
        redisTemplate.opsForValue().set(
                key,
                loginId,
                time,
                TimeUnit.MINUTES
        );

        return code;
    }

    /**
     * 验证邀请码是否有效
     * @param code 邀请码
     * @return 用户ID，如果无效返回null
     */
    @Override
    public Long validateInvitationCode(String code) {
        String key = INVITATION_PREFIX + code;
        String userIdStr = redisTemplate.opsForValue().get(key);

        if (userIdStr != null) {
            // 验证成功后删除key，防止重复使用
            redisTemplate.delete(key);
            return Long.parseLong(userIdStr);
        }
        return null;
    }




    /**
     * 生成随机邀请码（8位字母数字组合）
     */
    private String generateRandomCode() {
        String uuid = UUID.randomUUID().toString();
        return uuid.substring(0, 8).replace("-", "");
    }
}
