package com.water.watersys.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.water.watersys.model.domain.UserSys;
import com.water.watersys.mapper.UserSysMapper;
import com.water.watersys.model.dto.ChangePassword;
import com.water.watersys.model.dto.ChangeUserInfo;
import com.water.watersys.model.dto.LoginDto;
import com.water.watersys.model.dto.SearchUserDto;
import com.water.watersys.model.vo.UserOv;
import com.water.watersys.service.UserSysService;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.util.DigestUtils;

import java.util.List;
import java.util.Objects;

/**
* @author mac
* @description 针对表【user_sys】的数据库操作Service实现
* @createDate 2025-04-05 23:50:03
*/
@Service
public class UserSysServiceImpl extends ServiceImpl<UserSysMapper, UserSys>
    implements UserSysService {
    @Resource
    private UserSysMapper userSysMapper;

    @Override
    public int register(UserSys userSys) {
        String password = DigestUtils.md5DigestAsHex(userSys.getPassword().getBytes());
        userSys.setPassword(password);
        return userSysMapper.insert(userSys);
    }

    @Override
    public Integer login(LoginDto loginDto) {
        QueryWrapper<UserSys> userSysQueryWrapper = new QueryWrapper<>();
        String password = DigestUtils.md5DigestAsHex(loginDto.getPassword().getBytes());
        userSysQueryWrapper.eq("password", password);
        userSysQueryWrapper.eq("username", loginDto.getUsername());
        UserSys userSys = userSysMapper.selectOne(userSysQueryWrapper);
        if (userSys == null) {
            return 0;
        }else if (userSys.getStatus() == 0){
            return 0;
        }else {
            return userSys.getId();
        }
    }

    @Override
    public UserOv getUser(String loginId) {
        return userSysMapper.getUser(loginId);
    }

    @Override
    public Integer changePassword(ChangePassword changePassword, String loginId) {
        UserSys userSys = userSysMapper.selectById(loginId);
        String password = userSys.getPassword();
        if (Objects.equals(password, DigestUtils.md5DigestAsHex(changePassword.getOldPassword().getBytes()))) {
            String newPassword = changePassword.getNewPassword();
            changePassword.setNewPassword(DigestUtils.md5DigestAsHex(newPassword.getBytes()));
            return userSysMapper.changePassword(userSys.getId(),changePassword.getNewPassword());
        }else {
            return 0;
        }

    }

    @Override
    public Integer changeUserStatus(Integer status, String loginId) {
        LambdaUpdateWrapper<UserSys> lambdaUpdateWrapper = new LambdaUpdateWrapper<>();
        lambdaUpdateWrapper
                .eq(UserSys::getId, loginId)      // 条件：id = loginId
                .set(UserSys::getStatus, status); // 设置新的 status 值
        return userSysMapper.update(null, lambdaUpdateWrapper);
    }

    @Override
    public Integer changeUserInfo(ChangeUserInfo changeUserInfo, String loginId) {
        return userSysMapper.changeUserInfo(changeUserInfo,loginId);
    }

    @Override
    public List<UserOv> getUserList(String loginId, SearchUserDto searchUserDto) {
        return userSysMapper.getUserList(loginId,searchUserDto);
    }

    @Override
    public int postEmpUser(UserSys userSys) {
        return userSysMapper.insert(userSys);
    }

    @Override
    public int deleteEmpUser(Integer id) {
        return userSysMapper.deleteById(id);
    }

    @Override
    public Integer putEmpStatus(Integer id ,Integer status) {
        return userSysMapper.putEmpStatus(id,status);
    }


}




